#include "SliceMerger.hh"
#include "version.h"

int main(int argc, char ** argv)
{
  int retval = 0;
  Foundation * tf = NULL;

  try
  {
    string version = RequestManager::getVersionString(gVersionStr,
                                                      gRevisionStr);
    string dependencies = "xerces";
    string helptext = 
"Merges multiple Slice XML files into a singe <SliceRange> within a single\n"
"Slice file. The resultant <ReadCollection> will be renumbered and the \n"
"the coordinates of the each slice will be adjusted.\n"
"\n"
"  Usage: mergeSlice [options] slice1.xml [slice2.xml [...]]\n"
"\n"
"    slice1.xml First Slice XML file\n"
"    slice2.xml Second Slice XML file\n"
"\n"
"  Example Inputs: \n"
"  --------------------------\n"
"  slice1.xml     slice2.xml\n"
"  Slice 1 (A)    Slice 1 (G)\n"
"  Slice 2 (C)    Slice 2 (T)\n"
"\n"
"  Example Output:\n"
"  --------------------------\n"
"  Slice 1 (A)\n"
"  Slice 2 (C)\n"
"  Slice 3 (G)\n"
"  Slice 4 (T)\n"
 + RequestManager::getOptionHelp();
    // Instantiate a new Foundation object
    tf = new Foundation (version, helptext, dependencies, argc, argv);
    tf->disableOptionHelp();

    SliceMerger::handleOptions(tf);
    
    ReadMerger::StringList inputfiles = tf->getOptions()->getAllOtherData();
    SliceMerger::addSliceList(inputfiles);
    ReadMerger::StringList::const_iterator infile;

    if (inputfiles.size() == 0)
    {
      throw Exception("You must specify at least one file to merge",
                          "mergeSlice");
    }

    ReadMerger readManager;

    // Do first pass to load read data, sort offsets
    for (infile =  inputfiles.begin();
         infile != inputfiles.end();
         infile++)
    {
      retval += readManager.processFile(*infile, cerr);
    }

    if (!retval)
    {
      SliceMerger sliceManager(readManager);

      // Do second pass to merge slices
      string infilename;

      while ((infilename = readManager.getNextFile()) != "")
      {
        retval += sliceManager.processFile(infilename, cerr);
      }

      sliceManager.endSlices();
    }
  }
  catch (const ExitProgramNormally & e)
  {
    retval = 0;
  }
  catch (const Exception & e)
  {
    cerr << e << endl;
    retval = 100;
  }

  try
  {
    if (tf) delete tf;
  }
  catch (const Exception & e)
  {
    cerr << "Exception while deleting tf: " << e << endl;
    retval = 105;
  }

  return retval;
}
