#include "SliceOptimizer.hh"
#include "version.h"

int main(int argc, char ** argv)
{
  int retval = 0;
  string infile;

  Foundation * tf = NULL;

  try
  {
    string version = RequestManager::getVersionString(gVersionStr,
                                                      gRevisionStr);

    string dependencies = "xerces";
    string helptext = 
"Optimizes the alignment of the slices\n"
"\n"
"   Usage: optimizeSlice [options] slice.xml\n"
"\n"
"     slice.xml Slice XML file\n"
 + RequestManager::getOptionHelp();

    // Instantiate a new Foundation object
    tf = new Foundation (version, helptext, dependencies, argc, argv);
    tf->disableOptionHelp();

    SliceOptimizer::handleOptions(tf);
    SliceOptimizer manager;

    // Read the input filename
    if ((infile = tf->getOptions()->getNextOtherData()) == "")
    {
      throw Exception("You must specify a slice file", "optimizeSlice");
    }

    if (infile.find(".contig") != infile.npos)
    {
      retval = manager.processContigFile(infile, cerr);
    }
    else
    {
      // Process the slice file
      retval = manager.processFile(infile, cerr);
    }
  }
  catch (const ExitProgramNormally & e)
  {
    retval = 0;
  }
  catch (const Exception & e)
  {
    cerr << e << endl;
    retval = 100;
  }

  try
  {
    if (tf) delete tf;
  }
  catch (const Exception & e)
  {
    cerr << "Exception while deleting tf: " << e << endl;
    retval = 105;
  }

  return retval;
}
