#include "SequenceData.hh"
#include "Foundation.hh"
#include "Slice.h"

SequenceData::SequenceData(const ReadData * rd, 
                           long offset, 
                           long index,
                           bool isOriginSequence)
{
  if (!rd)
  {
    throw Exception("ReadData cannot be NULL",
                        "SequenceData::SequenceData");
  }

  m_originSequence = isOriginSequence;

  m_readData = rd;
  m_offset = offset;

  m_asmleft = m_asmright = index;

  m_negativeOffset = 0;
  m_negativeAsmleft = m_negativeAsmright = m_asmleft;

  m_nuc = "";
  m_nucright = "";
  m_inRight = false;
}

SequenceData::~SequenceData()
{ }

void SequenceData::addElement(long m_curOffset, long index, char nuc)
{

  if (!m_originSequence ||
      (!m_inRight && 
       m_curOffset == m_offset + (long) m_nuc.size()))
  {
    // Left sequence 
    m_nuc += nuc;
    m_asmright = index;
  }
  else
  {
    // In the right sequence
    if (!m_inRight)
    {
      m_inRight = true;
      m_negativeAsmleft = index;
    }

    // Count out the bases that we find on the right
    m_negativeOffset--;
    m_nucright += nuc;
    m_negativeAsmright = index;
  }
}

void SequenceData::print60(ostream & out, const string & bases)
{
  int count = 0;
  int printNewline = 1;

  string::const_iterator i;

  for (i = bases.begin();
       i != bases.end();
       i++)
  {
    out << *i;
    count++;
    printNewline = 1;

    if (count == 60)
    {
      out << endl;
      count = 0;

      printNewline = 0;
    }
  }

  if (printNewline) { out << endl; }
}

void SequenceData::printContigRecord(ostream & out)
{
  long asmleft;
  long offset;
  string bases;

  if (m_negativeOffset)
  {
    offset = m_negativeOffset;
    asmleft = m_negativeAsmleft - m_negativeAsmright;
    bases = m_nucright + m_nuc;
  }
  else
  {
    offset = m_offset;
    asmleft = m_asmleft;
    bases = m_nuc;
  }

  out << "#" << m_readData->getSeqname()
      << "(" << offset << ")";
  
  if (m_readData->isReverseCompliment())
  {
    out << " [RC] ";
  }
  else
  {
    out << " [] ";
  }

  out << bases.length() << " bases, 00000000 checksum. "
      << "{"   << m_readData->getSeqleft() 
      << " "   << m_readData->getSeqright()
      << "} <" << asmleft 
      << " "   << m_asmright 
      << ">" << endl;

  print60(out, bases);
}
