#include "TilingManager.hh"

TilingManager::TilingManager() : RequestManager("TilingManager")
{
  m_contigCount = 0;
  m_consensusSequence = NULL;
}

TilingManager::~TilingManager()
{
  ConsensusSequenceList::const_iterator i;
  for (i =  m_consensusSequenceList.begin();
       i != m_consensusSequenceList.end();
       i++)
  {
    delete *i;
  }
}

void TilingManager::addRequest(ConsensusRequest * requestData)
{
  RequestManager::addRequest(requestData);

  printHeader();
}

void TilingManager::addSliceRange(long & index, long & gindex)
{
  if (m_consensusSequence)
  {
    m_consensusSequence->flushSequences();
  }

  m_consensusSequence = new ConsensusSequence(m_contigCount, index, m_out);
  m_consensusSequenceList.push_back(m_consensusSequence);

  m_contigCount++;

  index = gindex = 0L;
}

void TilingManager::addSlice(SliceData * slice)
{
  RequestManager::addSlice(slice);

  m_consensusSequence->addSlice(slice);

  delete slice;
}

//! Prints the request header
/*! Prints all parameters from the constructor in the <Request ...> tag to
 *  the stored output stream.
 */
void TilingManager::printHeader()
{
  printXMLHeader();

  m_out << "<Request Type=\"Assembly\" Host=\"slice2tile\" User=\"slice2tile\">" << endl;
  m_out << "  <Source Project=\"default\" Number=\"default\" BacID=\"0\" ID=\"1\" Server=\"default\" />" << endl;
  m_out << "  <Assembly>" << endl; 
  m_out << "    <SequenceSet>" << endl;
}

int TilingManager::printResults()
{
  m_consensusSequence->flushSequences();

  m_out << "    </SequenceSet>" << endl;

  m_out << "    <LibrarySet />" << endl;
  m_out << "    <Links />" << endl;

  if (!m_errorCount)
  {
    m_out << "    <ContigSet>" << endl;
    ConsensusSequenceList::const_iterator i;
    for (i =  m_consensusSequenceList.begin();
         i != m_consensusSequenceList.end();
         i++)
    {
      (*i)->printTileXML("      ");
    }
    m_out << "    </ContigSet>" << endl;
  }
  m_out << "  </Assembly>" << endl;
  m_out << "</Request>" << endl;

  return m_errorCount;
}
