#include "SliceSplitter.hh"
#include "version.h"

int main(int argc, char ** argv)
{
  int retval = 0;
  string infile;

  Foundation * tf = NULL;

  try
  {
    string version = RequestManager::getVersionString(gVersionStr,
                                                      gRevisionStr);

    string dependencies = "xerces";
    string helptext = 
"Slice a slice file into multiple slice files based on a list of partition points\n"
"\n"
"   Usage: splitSlice [splitSlice Options] slice.xml\n"
"\n"
"     slice.xml Slice XML file\n"
"\n"
"   splitSlice Options\n"
"   ------------------\n"
"   -p <comma separated partions> List of slices to partition on (index)\n"
"   -f <filename> File containing list of slices to partition on (index)\n"
 + RequestManager::getOptionHelp();

    // Instantiate a new Foundation object
    tf = new Foundation (version, helptext, dependencies, argc, argv);
    tf->disableOptionHelp();

    SliceSplitter::handleOptions(tf);
    SliceSplitter manager;

    // Read the input filename
    if ((infile = tf->getOptions()->getNextOtherData()) == "")
    {
      throw Exception("You must specify a slice file", "splitSlice");
    }

    // Process the file
    retval = manager.processFile(infile, cerr);
  }
  catch (const ExitProgramNormally & e)
  {
    retval = 0;
  }
  catch (const Exception & e)
  {
    cerr << e << endl;
    retval = 100;
  }

  try
  {
    if (tf) delete tf;
  }
  catch (const Exception & e)
  {
    cerr << "Exception while deleting tf: " << e << endl;
    retval = 105;
  }

  return retval;
}
