#ifndef CONSENSUSDATA_HH
#define CONSENSUSDATA_HH 1

/*! @file
 *  @brief Defines interface for ConsensusData
 */

#include <string>
#include "Exceptions.hh"
#include "Slice.h"
#include "SliceData.hh"

namespace libSlice
{
  // For circular reference
  class SliceData;

  /*! @brief Stores information about the results of calculations on slices
   *  @ingroup cppinterface
   */

  //! Stores all of the results of calculations on slices
  /*! Different attributes can be queried without rerunning the calculations. If
   *  a different quality threshold is desired, set a new quality threshold in
   *  the slice data, and create a new consensus data result
   */
  class ConsensusData
  {
  public:
    ~ConsensusData();

    char         getConsensus()               const;
    char         getConsensusBase()           const;
    char         getAmbiguityCode()           const;
    char         getAmbiguityFlags()          const;

    int          getQualityClass()            const;

    int          getQualityValue()            const;
    int          getQualityValue(char base)   const;
    long double  getProbability(char base)    const;

    int          testAmbiguityCode(char base) const;

  private:
    ConsensusData(libSlice_Consensus * consensusResults, 
                  char ambiguityCode,
                  char qualityClass,
                  int m_doAmbiguity);

    libSlice_Consensus m_consensusResults;
    char m_qualityClass;
    char m_ambiguityCode;

    int m_doAmbiguity;

    //! Only SliceData can create ConsensusResult objects
    friend class SliceData;
  };

}

#endif
